Learn R Programming

ecolRxC (version 0.1.1-10)

print.summary.ecolRxC: Print a summary of a summary.ecolRxC object

Description

Print method for summary.ecolRxC objects

Usage

# S3 method for summary.ecolRxC
print(x, ..., margins = TRUE, digits = 2)

Value

No return value, called for side effects.

Arguments

x

An summary.ecolRxC class object.

...

Other arguments passed on to methods. Not currently used.

margins

A TRUE/FALSE argument informing if the margins of the transition matrix should be displayed. Default TRUE.

digits

Integer indicating the number of decimal places to be shown. Default, 2.