Print method for summary.ecolRxC objects
# S3 method for summary.ecolRxC
print(x, ..., margins = TRUE, digits = 2)No return value, called for side effects.
An summary.ecolRxC class object.
Other arguments passed on to methods. Not currently used.
A TRUE/FALSE argument informing if the margins of the transition matrix should be displayed. Default TRUE.
Integer indicating the number of decimal places to be shown. Default, 2.